PRINT N'Creating Table [dbo].[WorkGroupSupervisor]...';


GO
CREATE TABLE [dbo].[WorkGroupSupervisor] (
    [VCC]                  VARCHAR (50)  NOT NULL,
    [Description]          VARCHAR (50)  NOT NULL,
    [SupervisorId]         VARCHAR (250) NOT NULL,
    [CampaignId]           VARCHAR (250) NOT NULL,
    [AgentId]              VARCHAR (250) NOT NULL,
    [CreatedDate]          DATETIME      NULL,
    [CreatedByUserId]      VARCHAR (50)  NULL,
    [LastModifiedDate]     DATETIME      NULL,
    [LastModifiedByUserId] VARCHAR (50)  NULL,
    [TimeStamp]            VARCHAR (50)  NULL,
    PRIMARY KEY CLUSTERED ([VCC] ASC, [Description] ASC, [SupervisorId] ASC, [CampaignId] ASC, [AgentId] ASC)
);


GO
PRINT N'Creating Procedure [dbo].[GetWorkGroupsFromSupervisorEP]...';


GO
--exec [dbo].[GetWorkGroupsFromSupervisorEP] 'vccocc',''
CREATE PROCEDURE [dbo].[GetWorkGroupsFromSupervisorEP] (
	@VCC Varchar(50) = NULL, 
	@CampaignIds Varchar(MAX) = NULL
)
AS
BEGIN
	SET NOCOUNT ON
    IF @CampaignIds <> ''
    BEGIN 
        SELECT DISTINCT
            [Description]					'description',
            [SupervisorId]                  'supervisorId',
            [CampaignId]                    'campaignId',
            [AgentId]                       'agentId'
        FROM [WorkGroupSupervisor] (NOLOCK)
        WHERE [VCC] = @VCC
            AND [CampaignId]  IN (SELECT Value FROM [dbo].[split](@CampaignIds, ','))

          
	END
    ELSE
    BEGIN
         SELECT DISTINCT
            [Description]					'description',
            [SupervisorId]                  'supervisorId',
            [CampaignId]                    'campaignId',
            [AgentId]                       'agentId'
        FROM [WorkGroupSupervisor] (NOLOCK)
        WHERE [VCC] = @VCC

    END

		
	SET NOCOUNT OFF
END
GO
PRINT N'Creating Procedure [dbo].[GetWorkGroupsSupervisor]...';


GO
CREATE PROCEDURE [dbo].[GetWorkGroupsSupervisor] (
	@VCC Varchar(50) = NULL, 
	@SearchCriteria Varchar(50) = NULL, 
	@SearchExpression Varchar(50) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	SELECT DISTINCT
		[Description]					'description',
		[SupervisorId]                  'supervisorId'
	FROM [WorkGroupSupervisor] (NOLOCK)
	WHERE [VCC] = @VCC
		AND ISNULL([Description], '') LIKE CASE WHEN @SearchCriteria = 'description' THEN '%' + @SearchExpression + '%' ELSE '%' END
		
		
	SET NOCOUNT OFF
END
GO
PRINT N'Creating Procedure [dbo].[GetWorkGroupSupervisor]...';


GO
--exec [GetWorkGroupSupervisor] 'vccocc','icsupervisor'
CREATE PROCEDURE [dbo].[GetWorkGroupSupervisor] (
	@VCC Varchar(50) = NULL, @SupervisorId Varchar(250) = NULL
	)
AS
BEGIN
	SET NOCOUNT ON

	SELECT
		[Description]					'description',
		[SupervisorId]					'supervisorId',
		[CampaignID]					'campaignId',
		[agentId]					    'agentId'
		
	FROM [WorkGroupSupervisor] (NOLOCK)
	WHERE [VCC] = @VCC
    AND [SupervisorId] = @SupervisorId
	
	SET NOCOUNT OFF
END
GO
PRINT N'Creating Procedure [dbo].[SaveWorkGroupSupervisor]...';


GO

CREATE PROCEDURE [dbo].[SaveWorkGroupSupervisor] (
	@VCC Varchar(50) = NULL,
	@Description Varchar(50) = NULL,
	@SupervisorId Varchar(250) = NULL,
	@CampaignId Varchar(250) = NULL,
	@AgentId Varchar(250) = NULL,
	@CreatedDate Datetime = NULL,
	@CreatedByUserId Varchar(50) = NULL,
	@LastModifiedDate Datetime = NULL,
	@LastModifiedByUserId Varchar(50) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

		INSERT INTO [WorkGroupSupervisor] (
			[VCC], [Description], [SupervisorId], 
			[CampaignId], [AgentId],[CreatedDate], [CreatedByUserId], 
			[LastModifiedDate], [LastModifiedByUserId], [TimeStamp]
			)
		VALUES (
			@VCC, @Description, @SupervisorId,
			@CampaignId, @AgentId,@CreatedDate, @CreatedByUserId, 
			@LastModifiedDate, @LastModifiedByUserId, GETUTCDATE()
		)
		
	
    SELECT 1 AS 'result'
    
    SET NOCOUNT OFF
END
GO
PRINT N'Update complete.';


GO